@@ -21,8 +21,6 @@ our hashref $properties
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our void::method $empty_method = sub {
-    return 2;
-};
+sub empty_method { { my void::method $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
