@@ -22,8 +22,6 @@ our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our integer::method $empty_method = sub {
-    return 2;
-};
+sub empty_method { { my integer::method $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
