@@ -21,9 +21,7 @@ use RPerl::Test::Bar;
 our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS & SUBROUTINES ]]]
-our integer::method $empty_method = sub {
-    return 2;
-};
+# [[[ SUBROUTINES & OO METHODS ]]]
+sub empty_method { { my integer::method $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
