@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'ERROR ECOPAPL02' >>>
 # <<< PARSE_ERROR: 'Unrecognized escape \m passed through' >>>
 
 # [[[ HEADER ]]]
@@ -10,8 +10,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub {
-    return "\m\mfoo\m\mbar\m\m";
-};
+sub empty_sub { { my string $RETURN_TYPE }; return "\m\mfoo\m\mbar\m\m"; }
 
 1;    # end of package
