@@ -10,8 +10,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub {
-    return q{foo$123};
-};
+sub empty_sub { { my string $RETURN_TYPE }; return q{foo$123}; }
 
 1;    # end of package
