@@ -18,9 +18,10 @@ our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our void::method $empty_method = sub {
+sub empty_method {
+    { my void::method $RETURN_TYPE };
     ( my oject $self, my integer $foo ) = @ARG;
     return 2;
-};
+}
 
 1;    # end of class
