@@ -6,6 +6,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { ( my number_hashref $foo ) = @ARG; return 1; };
+sub empty_sub { { my void $RETURN_TYPE }; ( my number_hashref $foo ) = @ARG; return 1; }
 
 1;    # end of package
